;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "ivy-hydra" "20260213.941"
  "Additional key bindings for Ivy."
  '((emacs "24.5")
    (ivy   "0.15.1")
    (hydra "0.14.0"))
  :url "https://github.com/abo-abo/swiper"
  :commit "4defb814ce00fbbc2cf2ad626e630a39f4da1456"
  :revdesc "4defb814ce00"
  :keywords '("convenience")
  :authors '(("Oleh Krehel" . "ohwoeowho@gmail.com"))
  :maintainers '(("Basil L. Contovounesios" . "basil@contovou.net")))
